#!/bin/bash
#****f*  Album-Index/Album-TOC
# NAME
#  create_album_directory.sh
#
# FUNCTION
#   Sub-program of create_album_index.sh
#   Converts a raw album directory into a proper HTML album directory file
#   w/ links to each song info file
#***

mp3db2_cfg_file="$HOME/.mp3db2rc"

function load_cfg {
# Loads the Configuration file.
if ! source "$mp3db2_cfg_file"
then
echo "Error loading configuration file: $mp3db2_cfg_file"
echo 'Perhaps you need to run the configure script for this package?'
exit 1
fi
# Now sanity check some variables.
if test ! -d "$data_dir"
then
if [ "$data_dir" = '' ]
then
echo 'Error no data directory has been defined.'
echo 'Perhaps you need to run the configure script for this package?'
exit 1
else
# The directory just doesn't exist.
echo "Error the data directory: $data_dir: does not exist."
exit 1
fi
fi
return 0
} 
# End function.

write_html_header ()
{ cat ${script_path}/contrib/mp3db_html/html_doctype.template
  echo "<HTML>"
  echo "<HEAD>"
  cat ${script_path}/contrib/mp3db_html/html_metatags.template
  echo "<TITLE>${title}</TITLE>"
  echo '<link rel="stylesheet" type="text/css" href="../format.css">'  
  echo "</HEAD>"
  echo "<BODY>"
}

write_html_trailer ()
{ echo "</BODY>"
  echo "</HTML>"
}

album_directory ()
{ 
### Page header section w/ title and link to album index page
  echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP><COL SPAN=3></COLGROUP>"
  echo "<TR>"
  echo "<TD ALIGN=left><H2>Album :</H2></TD>"
  echo "<TD ALIGN=center><H2>${title}</H2></TD>"
  echo "<TD ALIGN=right><A HREF=\"index.html\" CLASS=\"DBL\">Album Index</A></TD>"
  echo "</TR>"
  echo "</TABLE>"
  echo "<P>"

### Table headers
  echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP><COL><COL><COL><COL></COLGROUP>"
  echo "<TR><TH ALIGN=left>Title</TH><TH ALIGN=left>Filename</TH><TH ALIGN=left>Artist / Group</TH></TR>"

  cat "$if" | while read record                     # Read raw file line by line
  do
    filename=`echo $record | cut -d\| -f1`
    title=`echo $record | cut -d\| -f2`
	test "X$title" = "X" && title="Unknown"         # No null strings, please
	title=`echo $title | sed -e"s/&/&amp;/"`        # R & R has to be R &amp; R
    artist=`echo $record | cut -d\| -f3`
	artist=`echo $artist | sed -e"s/&/&amp;/"`
	test "X$artist" = "X" && artist="Unknown"
    echo "<TR>"
    info_file=${filename%.mp3}                      # Truncate file name extension
	filename=`echo $filename | sed -e"s/&/&amp;/"`
    info_file=`echo $info_file | tr "#" "_" | sed -e"s/&/&amp;/"`
    echo "<TD ALIGN=left>$title</TD>"
    href="../${file_index_dir}/${info_file}.html"   # HREF link to song info file
    echo "<TD ALIGN=left><A HREF=\"$href\">$filename</A></TD>"
    art_file=`echo $artist | tr "/" "_"`            # Convert ugly chars to '_'
    href="../${art_index_dir}/${art_file}.html"     # HREF link to artist info
    echo "<TD ALIGN=left><A HREF=\"$href\">$artist</A></TD>"
    echo "</TR>"
  done
  echo "</TABLE>"
}
##################################################################################
####                                     MAIN                                  ###

load_cfg
if="$*"                                             # File name may contain blanks
title=${if%.raw}                                    # Truncate extension
title=${title:2}                                    # Remove prefix "./"
title=`echo $title | tr "#/" "__"`                  # Convert ugly chars to '_'
of=${html_dir}/${alb_index_dir}/${title}.html       # Album directory file name
test -f "$of" && rm -f "$of"                        # Delete file if it exists

# echo "Creating HTML content list of $of ..." >&2

write_html_header   > "$of"                         # Write new album directory
album_directory    >> "$of"
write_html_trailer >> "$of"

rm -f "$if"                                         # Delete raw file

exit 0                                            # Be nice and give return status

