#!/bin/bash
#****f*  Main-Page/Album-Index
# NAME
#  create_album_index.sh
#
# FUNCTION
#   Creates the album index and calls sub-program to generate the directory HTML
#   for each album
#
#   May be started stand-alone for re-creating the album index and album 
#   directories only
#***

mp3db2_cfg_file="$HOME/.mp3db2rc"

function load_cfg {
# Loads the Configuration file.
if ! source "$mp3db2_cfg_file"
then
echo "Error loading configuration file: $mp3db2_cfg_file"
echo 'Perhaps you need to run the configure script for this package?'
exit 1
fi
# Now sanity check some variables.
if test ! -d "$data_dir"
then
if [ "$data_dir" = '' ]
then
echo 'Error no data directory has been defined.'
echo 'Perhaps you need to run the configure script for this package?'
exit 1
else
# The directory just doesn't exist.
echo "Error the data directory: $data_dir: does not exist."
exit 1
fi
fi
return 0
} 
# End function.

write_html_header ()
{ cat ${script_path}/contrib/mp3db_html/html_doctype.template
  echo "<HTML>"
  echo "<HEAD>"
  cat ${script_path}/contrib/mp3db_html/html_metatags.template
  echo "<TITLE>${title}</TITLE>"
  echo '<link rel="stylesheet" type="text/css" href="../format.css">'  
  echo "</HEAD>"
  echo "<BODY>"
}

write_html_trailer ()
{ echo "</BODY>"
  echo "</HTML>"
}

create_album_index ()
{ 
### Page header section w/ title and link to database root page
  echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP> <COL WIDTH='33%'> <COL WIDTH='34%'> <COL WIDTH='33%'> </COLGROUP>"
  echo "<TR>"
  echo "<TD ALIGN=left> </TD>"
  echo "<TD ALIGN=center><H2>${title}</H2></TD>"
  echo "<TD ALIGN=right><A HREF=\"../index.html\" CLASS=\"DBL\">MP3 Database</A></TD>"
  echo "</TR>"
  echo "</TABLE>"
  echo "<P>"

### Alphabetical index section w/ links on album name
  numkeys=`cut -c1 $album_list | sort -udf | wc -l` # Get no. of table columns
  echo "<TABLE ALIGN=center>"
  echo "<COLGROUP> <COL SPAN=${numkeys}></COLGROUP>"
  echo "<TR>"
  cut -c1 $album_list | sort -udf | while read key  # Fill row w/ unique 1st chars
  do                                                # of album list
      echo "<TD><A HREF=\"#${key}\" CLASS=\"ALPHA_INDEX\">$key </A></TD>"
  done
  echo "</TR>"
  echo "</TABLE>"
  echo "<P>"

### The album table starts here
  echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP><COL SPAN=2></COLGROUP>"
  echo "<TR><TH ALIGN=left><H3>Album</H3></TH> <TH ALIGN=left><H3>Artist / Group</H3></TH></TR>"
  key=""                                            # Reset current key index

  cat $album_list | while read record               # Process album list line by
  do                                                # line
    album=`echo $record | cut -d\| -f1`
    artist=`echo $record | cut -d\| -f2`
    echo "<TR>"
    echo "<TD ALIGN=left>"

	newkey=`echo $album | cut -c1`                  # Get 1st char of album name
	if [ "$newkey" != "$key" ]                      # 1st char changed ?
	then
        echo "<A NAME=\"$newkey\"></A>"             # Yes, write anchor and
		key=$newkey                                 # remember "new" 1st char
	fi
    alb_file=`echo $album | tr "#/" "__"`           # Remove '#', '/' from album
    href="${alb_file}.html"                         # name and build href link
    echo "<A HREF=\"$href\">$album</A></TD>"
    art_file=`echo $artist | tr "/" "_"`            # Some procedure for artist
    href="../${art_index_dir}/${art_file}.html"     # name and write table record
    echo "<TD ALIGN=left><A HREF=\"$href\">$artist</A></TD>"
    echo "</TR>"
  done
  echo "</TABLE>"
}
##################################################################################
####                                     MAIN                                  ###

 load_cfg

of=${html_dir}/${alb_index_dir}/index.html          # The album index HTML file
title="Album Index"                                 # The HTML page title
cd $data_dir                                        # The MP3DB2 database is here
tmpdb=${html_dir}/tmpdb.$$                          # Two temporary files we need
album_list=${html_dir}/album_list.$$
touch $album_list                                   # Create this one empty
echo "Creating album index ..." >&2

rm -rf ${html_dir}/$alb_index_dir ; mkdir -p ${html_dir}/$alb_index_dir # Scratch
													# & re-create the album dir.
cat $mask > $tmpdb                                  # Join all MP3DB2 db files
                                                    # into one big temp database
cat $tmpdb | while read record                      # Process temp db line by line
do
  artist=`echo $record | cut -d\| -f3`
  test "X$artist" = "X" && artist="Unknown"         # No null strings, please
  album=`echo $record | cut -d\| -f4`
  test "X$album" = "X" && album="Unknown"
  echo "${album}\|${artist}" >> $album_list
  alb_file=`echo $album | tr "#/" "__"`             # Remove '#', '/' from album
													# name and create raw record
  echo "$record" >> "${html_dir}/${alb_index_dir}/${alb_file}.raw"
done
sort -udf $album_list > ${album_list}.2             # Create list sorted by 
mv ${album_list}.2 $album_list ; rm -f ${album_list}.2  # album name

write_html_header   > $of                           # Write HTML album index 
create_album_index >> $of
write_html_trailer >> $of

cd ${html_dir}/$alb_index_dir                       # Convert raw records into
													# HTML album directories
find . -name \*.raw -exec ${script_path}/contrib/mp3db_html/create_album_directory.sh  \{\} \;

rm -f $tmpdb $album_list

exit 0                                            # Be nice and give return status

