#!/bin/bash
#****h* Artist-Index/Artist-Songlist
# NAME
#  create_artist_directory.sh
#
# FUNCTION
#   Sub-program of create_artist_index.sh
#   Converts a raw artist directory into a proper HTML artist directory file
#   w/ links to each song info file
#***

mp3db2_cfg_file="$HOME/.mp3db2rc"

function load_cfg {
# Loads the Configuration file.
if ! source "$mp3db2_cfg_file"
then
echo "Error loading configuration file: $mp3db2_cfg_file"
echo 'Perhaps you need to run the configure script for this package?'
exit 1
fi
# Now sanity check some variables.
if test ! -d "$data_dir"
then
if [ "$data_dir" = '' ]
then
echo 'Error no data directory has been defined.'
echo 'Perhaps you need to run the configure script for this package?'
exit 1
else
# The directory just doesn't exist.
echo "Error the data directory: $data_dir: does not exist."
exit 1
fi
fi
return 0
} 
# End function.

write_html_header ()
{ cat ${script_path}/contrib/mp3db_html/html_doctype.template
  echo "<HTML>"
  echo "<HEAD>"
  cat ${script_path}/contrib/mp3db_html/html_metatags.template
  echo "<TITLE>${title}</TITLE>"
  echo '<link rel="stylesheet" type="text/css" href="../format.css">'  
  echo "</HEAD>"
  echo "<BODY>"
}

write_html_trailer ()
{ echo "</BODY>"
  echo "</HTML>"
}

artist_directory ()
{ 
### Page header section w/ title and link to artist index page
  echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP><COL SPAN=3></COLGROUP>"
  echo "<TR>"
  echo "<TD ALIGN=left><H2>Artist/Group :</H2></TD>"
  echo "<TD ALIGN=center><H2>${title}</H2></TD>"
  echo "<TD ALIGN=right><A HREF=\"index.html\" CLASS=\"DBL\">Artist/Group Index</A></TD>"
  echo "</TR>"
  echo "</TABLE>"
  echo "<P>"

### Table headers
  echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP><COL><COL> </COLGROUP>"
  echo "<TR><TH ALIGN=left>Album</TH><TH ALIGN=left>Title</TH></TR>"

  cat "$if" | while read record                     # Read raw file line by line
  do
    filename=`echo $record | cut -d\| -f1`
    title=`echo $record | cut -d\| -f2`
    test "X$title" = "X" && title="Unknown"         # No null strings, please
	title=`echo $title | sed -e"s/&/&amp;/"`        # R & R has to be R &amp; R
    artist=`echo $record | cut -d\| -f3`
    test "X$artist" = "X" && artist="Unknown"
    album=`echo $record | cut -d\| -f4`
    test "X$album" = "X" && album="Unknown"
    echo "<TR>"
    alb_file=`echo $album | tr "#/" "__"`           # Convert ugly chars to '_'
    href="../${alb_index_dir}/${alb_file}.html"     # HREF link to album info
    echo "<TD ALIGN=left><A HREF=\"$href\">$album</A></TD>"
    file=${filename%.mp3}                           # Truncate file name extension
    file=`echo $file | tr "#" "_" | sed -e"s/&/&amp;/"`
    href="../${file_index_dir}/${file}.html"        # HREF link to song info
    echo "<TD ALIGN=left><A HREF=\"$href\">$title</A></TD>"
    echo "</TR>"
  done
  echo "</TABLE>"
}

##############################################################################
# MAIN

load_cfg

if="$*"                                             # File name may contain blanks
title=${if%.raw}                                    # Truncate extension
title=${title:2}                                    # Remove prefix "./"
title_file=`echo $title | tr "/" "_"`               # Convert ugly chars to '_'
of=${html_dir}/${art_index_dir}/${title_file}.html  # Artist directory file name
test -f "$of" && rm -f "$of"                        # Delete file if it exists

# echo "Creating HTML content list of $of ..." >&2

write_html_header   > "$of"                         # Write new artist directory
artist_directory   >> "$of"
write_html_trailer >> "$of"

rm -f "$if"                                         # Delete raw file

exit 0                                            # Be nice and give return status

