#!/bin/bash
#****f*  Main-Page/CD-Index
#
# NAME
#   create_cd_index.sh
# 
# FUNCTION
#   Creates the cd index and calls sub-program to generate the directory HTML
#   for each cd
#
#   May be started stand-alone for re-creating the cd index and cd 
#   directories only
#***

mp3db2_cfg_file="$HOME/.mp3db2rc"

function load_cfg {
# Loads the Configuration file.
if ! source "$mp3db2_cfg_file"
then
echo "Error loading configuration file: $mp3db2_cfg_file"
echo 'Perhaps you need to run the configure script for this package?'
exit 1
fi
# Now sanity check some variables.
if test ! -d "$data_dir"
then
if [ "$data_dir" = '' ]
then
echo 'Error no data directory has been defined.'
echo 'Perhaps you need to run the configure script for this package?'
exit 1
else
# The directory just doesn't exist.
echo "Error the data directory: $data_dir: does not exist."
exit 1
fi
fi
return 0
} 
# End function.

write_html_header ()
{ cat ${script_path}/contrib/mp3db_html/html_doctype.template
  echo "<HTML>"
  echo "<HEAD>"
  cat ${script_path}/contrib/mp3db_html/html_metatags.template
  echo "<TITLE>${title}</TITLE>"
  echo '<link rel="stylesheet" type="text/css" href="../format.css">'  
  echo "</HEAD>"
  echo "<BODY>"
}

write_html_trailer ()
{ echo "</BODY>"
  echo "</HTML>"
}

create_cd_index ()
{ 
### Page header section w/ title and link to database root page
  cd $data_dir
  echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP> <COL WIDTH='33%'> <COL WIDTH='34%'> <COL WIDTH='33%'> </COLGROUP>"
  echo "<TR>"
  echo "<TD ALIGN=left> </TD>"
  echo "<TD ALIGN=center><H2>${title}</H2></TD>"
  echo "<TD ALIGN=right><A HREF=\"../index.html\" CLASS=\"DBL\">MP3 Database</A></TD>"
  echo "</TR>"
  echo "</TABLE>"
  echo "<P>"

### Alphabetical index section w/ links on album name
  numkeys=`ls $mask | cut -c1 | sort -udf | wc -l`   # Get no. of table columns
  echo "<TABLE ALIGN=center>"
  echo "<COLGROUP> <COL SPAN=${numkeys}></COLGROUP>"
  echo "<TR>"
  ls $mask | cut -c1 | sort -udf | while read key    # Fill row w/ unique 1st char
  do                                                 # of cd list
      echo "<TD><A HREF=\"#${key}\" CLASS=\"ALPHA_INDEX\">$key </A></TD>"
  done
  echo "</TR>"
  echo "</TABLE>"
  echo "<P>"

### The cd table starts here
  echo "<TABLE WIDTH='100%'>"
  echo "<colgroup> <col> </colgroup>"
  key=""                                             # Reset current key index

  ls $mask | while read cd_name                      # Process cd list line by
  do                                                 # line
    echo "<TR>"
    echo "<TD ALIGN=center>"

	newkey=`echo $cd_name | cut -c1`                 # Get 1st char of cd name
	if [ "$newkey" != "$key" ]                       # 1st char changed ?
	then
        echo "<A NAME=\"$newkey\"></A>"              # Yes, write anchor and
		key=$newkey                                  # remember "new" 1st char
	fi

    echo "<A HREF=\"${cd_name}.html\">${cd_name%.$mask}</A></TD>" # Build href link
    echo "</TR>"

    ${script_path}/contrib/mp3db_html/create_cd_directory.sh $cd_name # Create cd directory
  done

  echo "</TABLE>"
}

##############################################################################
# MAIN

load_cfg

test ! -d ${html_dir}/$cd_index_dir && mkdir -p ${html_dir}/$cd_index_dir
of=${html_dir}/${cd_index_dir}/index.html               # The cd index HTML file
title="CD Index"                                        # The HTML page title
test -f $of && rm -f $of                                # Scratch & re-create the
                                                        # cd directory HTML file
echo "Creating CD index $of ..." >&2

write_html_header   > $of                               # Write HTML cd index and
create_cd_index    >> $of                               # each cd HTML directory
write_html_trailer >> $of

exit 0                                            # Be nice and give return status

