#!/bin/bash
#****h* Main-Page/MP3-File-Info
# NAME
#  create_file_info.sh
#
# FUNCTION
#   Sub-program of create_html.sh
#   Creates the HTML Info files for each .mp3 file
# 
#   May be started stand-alone
#***

mp3db2_cfg_file="$HOME/.mp3db2rc"

function load_cfg {
# Loads the Configuration file.
if ! source "$mp3db2_cfg_file"
then
echo "Error loading configuration file: $mp3db2_cfg_file"
echo 'Perhaps you need to run the configure script for this package?'
exit 1
fi
# Now sanity check some variables.
if test ! -d "$data_dir"
then
if [ "$data_dir" = '' ]
then
echo 'Error no data directory has been defined.'
echo 'Perhaps you need to run the configure script for this package?'
exit 1
else
# The directory just doesn't exist.
echo "Error the data directory: $data_dir: does not exist."
exit 1
fi
fi
return 0
} 
# End function.

write_html_header ()
{ cat ${script_path}/contrib/mp3db_html/html_doctype.template
  echo "<HTML>"
  echo "<HEAD>"
  cat ${script_path}/contrib/mp3db_html/html_metatags.template
  echo "<TITLE>${title}</TITLE>"
  echo '<link rel="stylesheet" type="text/css" href="../format.css">'  
  echo "</HEAD>"
  echo "<BODY>"
}

write_html_trailer ()
{ echo "</BODY>"
  echo "</HTML>"
}

##################################################################################
####                                     MAIN                                  ###

load_cfg

echo "Creating file infos ..." >&2

cd $data_dir                                        # Here are the MP3DB2 files
test ! -d ${html_dir}/$file_index_dir && mkdir -p ${html_dir}/$file_index_dir  # Create the info file
                                                    # directory if necessary
cat $mask | while read record                       # Join all MP3DB2 files
do                                                  # into one big list
  filename=`echo $record | cut -d\| -f1`            # Read all columns we need . .
  title=`echo $record | cut -d\| -f2`
  test "X$title" = "X" && title=" "                 # . convert all null strings
  title=`echo $title | sed -e"s/&/&amp;/"`          # R & R has to be R &amp; R
  artist=`echo $record | cut -d\| -f3`              # into a single blank
  test "X$artist" = "X" && artist=" "
  artist=`echo $artist | sed -e"s/&/&amp;/"`
  album=`echo $record | cut -d\| -f4`
  test "X$album" = "X" && album=" "
  album=`echo $album | sed -e"s/&/&amp;/"`
  year=`echo $record | cut -d\| -f5`
  test "X$year" = "X" && year=" "
  comment=`echo $record | cut -d\| -f6`
  test "X$comment" = "X" && comment=" "
  genre=`echo $record | cut -d\| -f7`
  test "X$genre" = "X" && genre=" "
  genre=`echo $genre | sed -e"s/&/&amp;/"`
  bitrate=`echo $record | cut -d\| -f8`
  test "X$bitrate" = "X" && bitrate=" "
  playtime=`echo $record | cut -d\| -f9`
  test "X$playtime" = "X" && playtime=" "
  size=`echo $record | cut -d\| -f10`
  test "X$size" = "X" && size=" "
  directory=`echo $record | cut -d\| -f11`
  test "X$directory" = "X" && directory=" "

  file=${filename%.mp3}                             # Truncate file name extension
  file=`echo $file | tr "#" "_"`                    # Convert ugly chars to '_'
  of=${html_dir}/${file_index_dir}/${file}.html     # The HTML info file name

  write_html_header                                                         >"$of"
                                                    # Write the HTML table headers
  echo "<TABLE WIDTH='100%'>"                                              >>"$of"
  echo "<COLGROUP><COL WIDTH='13%'><COL WIDTH='74%'><COL WIDTH='13%'></COLGROUP>">>"$of"
  echo "<TR>"                                                              >>"$of"
  echo "<TD ALIGN=left><H2>Title :</H2></TD>"                              >>"$of"
  echo "<TD ALIGN=center><H2>$title</H2></TD>"                             >>"$of"
  echo "<TD ALIGN=right> </TD>"                                            >>"$of"
  echo "</TR>"                                                             >>"$of"
  echo "</TABLE>"                                                          >>"$of"
  echo "<P>"                                                               >>"$of"
                                                    # Write the HTML table
  echo "<TABLE ALIGN=center WIDTH='80%' BORDER=2 CLASS=\"FILE_INFO\">"     >>"$of"
  echo "<COLGROUP><COL SPAN=2></COLGROUP>"                                 >>"$of"

  echo "<TR><TD ALIGN=left>Artist</TD><TD ALIGN=left>$artist</TD></TR>"    >>"$of"
  echo "<TR><TD ALIGN=left>Title</TD><TD ALIGN=left>$title</TD></TR>"      >>"$of"
  echo "<TR><TD ALIGN=left>Album</TD><TD ALIGN=left>$album</TD></TR>"      >>"$of"
  echo "<TR><TD ALIGN=left>Year</TD><TD ALIGN=left>$year</TD></TR>"        >>"$of"
  echo "<TR><TD ALIGN=left>Comment</TD><TD ALIGN=left>$comment</TD></TR>"  >>"$of"
  echo "<TR><TD ALIGN=left>Genre</TD><TD ALIGN=left>$genre</TD></TR>"      >>"$of"
  echo "<TR><TD ALIGN=left>Bitrate</TD><TD ALIGN=left>$bitrate</TD></TR>"  >>"$of"
  echo "<TR><TD ALIGN=left>Playtime</TD><TD ALIGN=left>$playtime</TD></TR>">>"$of"
  echo "<TR><TD ALIGN=left>Size</TD><TD ALIGN=left>$size</TD></TR>"        >>"$of"
  echo "<TR><TD ALIGN=left>Directory</TD><TD ALIGN=left>$directory</TD></TR>">>"$of"
  echo "</TABLE>"                                                          >>"$of"
  write_html_trailer                                                       >>"$of"
done

exit 0                                            # Be nice and give return status

