#!/bin/bash
#****f*  MP3DB2/Main-Page
# NAME
#   create_html.sh
# 
# FUNCTION
#   Main script for creating the MP3DB2 HTML database
#   Creates the root index.html and calls sub-programs for creating the
#   CD index, album index, artist index, song index
#***

mp3db2_cfg_file="$HOME/.mp3db2rc"

function load_cfg {
# Loads the Configuration file.
if ! source "$mp3db2_cfg_file"
then
echo "Error loading configuration file: $mp3db2_cfg_file"
echo 'Perhaps you need to run the configure script for this package?'
exit 1
fi
# Now sanity check some variables.
if test ! -d "$data_dir"
then
if [ "$data_dir" = '' ]
then
echo 'Error no data directory has been defined.'
echo 'Perhaps you need to run the configure script for this package?'
exit 1
else
# The directory just doesn't exist.
echo "Error the data directory: $data_dir: does not exist."
exit 1
fi
fi
return 0
} 
# End function.

write_html_header ()
{ cat ${script_path}/contrib/mp3db_html/html_doctype.template
  echo "<HTML>"
  echo "<HEAD>"
  cat ${script_path}/contrib/mp3db_html/html_metatags.template
  echo "<TITLE>${title}</TITLE>"
  echo '<link rel="stylesheet" type="text/css" href="format.css">'  
  echo "</HEAD>"
  echo "<BODY>"
}

write_html_trailer ()
{ echo "</BODY>"
  echo "</HTML>"
}

write_page ()
{ echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP><COL WIDTH='33%'><COL WIDTH='34%'><COL WIDTH='33%'></COLGROUP>"
  echo "<TR>"
  echo "<TD> </TD>"
  echo "<TD ALIGN=center><H1>${title}</H1></TD>"
  echo "<TD ALIGN=right><A HREF=\"docindex.html\" CLASS=\"DBL\">About MP3DB2-HTML</A></TD>"
  echo "</TR>"
  echo "</TABLE>"

  echo "<P>"

  echo "<TABLE WIDTH='100%'>"
  echo "<COLGROUP><COL WIDTH='33%'><COL WIDTH='34%'><COL WIDTH='33%'></COLGROUP>"

  echo "<TR>"
  echo "<TD ALIGN=center><H3><A HREF=\"${cd_index_page}\">CD Index</A></H3></TD>"
  echo "<TD ALIGN=center><H3><A HREF=\"${alb_index_page}\">Album Index</A></H3></TD>"
  echo "<TD ALIGN=center><H3><A HREF=\"${art_index_page}\">Artist / Group Index</A></H3></TD>"
  echo "</TR>"
  echo "</TABLE>"
}
##################################################################################
####                                     MAIN                                  ###

load_cfg

of=${html_dir}/index.html                     # This is the root page of our
title="MP3 Database"                          # HTML database
cd_index_page="${cd_index_dir}/index.html"    # Here's the CD index
alb_index_page="${alb_index_dir}/index.html"  # . . the album index
art_index_page="${art_index_dir}/index.html"  # . . the artist index

test ! -d $html_dir && mkdir -p $html_dir     # Create directory if necessary . .
test -f ${of} && rm -f ${of}                  # Scratch the root page . .

echo "Creating main HTML page $of ..." >&2
write_html_header   > $of                     # . . and create a new one
write_page         >> $of
write_html_trailer >> $of

${script_path}/contrib/mp3db_html/create_cd_index.sh     # Create CD index page,
${script_path}/contrib/mp3db_html/create_album_index.sh  # . the album index,
${script_path}/contrib/mp3db_html/create_artist_index.sh # . the artist index,
${script_path}/contrib/mp3db_html/create_file_info.sh    # . the file (song) index

# Copy supplementary files to the root of the html index
cp -p \
    ${script_path}/contrib/mp3db_html/docindex.html \
    ${script_path}/contrib/mp3db_html/doc01.jpg \
    ${script_path}/contrib/mp3db_html/doc01.html \
    ${script_path}/contrib/mp3db_html/format.css \
    ${script_path}/contrib/mp3db_html/mp3db2.jpg \
    $html_dir

exit 0                                        # Be nice and give return status

